@@ -403,7 +403,9 @@ class Task:
                 ] = (
                     extracted_result.to_valid_dict()
                 )  # put our data into the result Item
-                self.session.item.save(result)  # save the item back to qalx
+                self.session.item.save(
+                    result, as_file=result.data["as_file"]
+                )  # save the item back to qalx
             except Exception as err:  # something went wrong
                 msg = f"Failed to extract result with guid {result_guid}:\n\n{err}"
                 self.session.log.error(msg + "\n\n" + traceback.format_exc())
