@@ -486,6 +486,7 @@ class RangeGraph:
     object_extra: ObjectExtra = ObjectExtra()
     storm_duration_hours: float = 3.0
     meta: ResultMeta = ResultMeta()
+    as_file: bool = False
 
     _type: str = "rg"
 
@@ -516,6 +517,7 @@ class RangeGraph:
             ),
             storm_duration_hours=a_dict.get("storm_duration_hours", 3.0),
             meta=ResultMeta(**a_dict.get("meta", ResultMeta().__dict__)),
+            as_file=a_dict.get("as_file", False),
         )
 
     def hashable_meta(self):
@@ -553,6 +555,7 @@ class TimeHistory:
         :param period [Period]:
         :param object_extra [ObjectExtra]:  (default=ObjectExtra())
         :param meta [ResultMeta]:  (default=ResultMeta())
+        :param as_file [bool]:
 
     Available after the simulation has been post-processed:
         :param extracted: ExtractedTimeHistory = ExtractedTimeHistory()
@@ -564,6 +567,7 @@ class TimeHistory:
     extracted: ExtractedTimeHistory = ExtractedTimeHistory()
     object_extra: ObjectExtra = ObjectExtra()
     meta: ResultMeta = ResultMeta()
+    as_file: bool = False
 
     _type: str = "th"
 
@@ -582,6 +586,7 @@ class TimeHistory:
                 **a_dict.get("extracted", ExtractedTimeHistory().__dict__)
             ),
             meta=ResultMeta(**a_dict.get("meta", ResultMeta().__dict__)),
+            as_file=a_dict.get("as_file", False),
         )
 
     def to_valid_dict(self):
